hashid

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2019 License: GPL-3.0 Imports: 2 Imported by: 1

README

hashid

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ProtoType

type ProtoType []struct {
	Regex string `json:"regex"`
	Modes []struct {
		John     string `json:"john"`
		Hashcat  *int   `json:"hashcat,omitempty"`
		Extended bool   `json:"extended"`
		Name     string `json:"name"`
	} `json:"modes"`
}

ProtoType describes the hash and format codes for HashCat and JohnTheRipper

func GetHashType

func GetHashType(hash string) (hashTypes ProtoType, err error)

GetHashType returns the possible hash types, as well as their HashCat and JohnTheRipper formats.

Directories

Path Synopsis

Jump to