Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProtoType ¶
type ProtoType []struct {
Regex string `json:"regex"`
Modes []struct {
John string `json:"john"`
Hashcat *int `json:"hashcat,omitempty"`
Extended bool `json:"extended"`
Name string `json:"name"`
} `json:"modes"`
}
ProtoType describes the hash and format codes for HashCat and JohnTheRipper
func GetHashType ¶
GetHashType returns the possible hash types, as well as their HashCat and JohnTheRipper formats.
Click to show internal directories.
Click to hide internal directories.